fabricpy package modules
==========================

This section contains detailed documentation for each module in the fabricpy package.

Submodules
----------

fabricpy.modconfig module
-------------------------

.. automodule:: fabricpy.modconfig
   :members:
   :show-inheritance:
   :undoc-members:

fabricpy.item module
--------------------

.. automodule:: fabricpy.item
   :members:
   :show-inheritance:
   :undoc-members:

fabricpy.fooditem module
------------------------

.. automodule:: fabricpy.fooditem
   :members:
   :show-inheritance:
   :undoc-members:

fabricpy.block module
---------------------

.. automodule:: fabricpy.block
   :members:
   :show-inheritance:
   :undoc-members:

fabricpy.itemgroup module
-------------------------

.. automodule:: fabricpy.itemgroup
   :members:
   :show-inheritance:
   :undoc-members:

fabricpy.recipejson module
--------------------------

.. automodule:: fabricpy.recipejson
   :members:
   :show-inheritance:
   :undoc-members:

fabricpy.item\_group module
---------------------------

.. automodule:: fabricpy.item_group
   :members:
   :show-inheritance:
   :undoc-members:
   :no-index:
